﻿---
--- Created by 决定吃小菜.
--- DateTime: 2025-06-30 01:59:25
--- c++端api文档说明

---@meta
---@diagnostic disable: lowercase-global, missing-return

---@class lib C++函数库，包含常用的绘制相关函数
lib = {} -- C++函数库，包含常用的绘制相关函数

--- 打印调试信息
---@param msg string
function lib.Debug(msg) end

--- 打印异常信息
---@param msg string
function lib.Error(msg) end

--- 输出SDL版本信息到debug
function lib.SDLVersion() end

--- 获取按键
---@return number, number, number, number, number
function lib.GetKey() end

--- 获取按键状态
---@param key number 按键代号
---@return boolean
function lib.GetKeyState(key) end

---@deprecated 已废弃
function lib.EnableKeyRepeat() end

--- 延迟（睡眠），单位毫秒
---@param ms number
function lib.Delay(ms) end

--- 返回SDL的tick，也就是程序运行了多久
---@return number time 毫秒
function lib.GetTime() end

--- 获取GUID
---@return string
function lib.GetGuid() end

--- 简繁转换
---@param str string 字符串
---@param flag number 1繁转简，2简转繁
---@return string
function lib.CharSet(str, flag) end

--- UI层，绘制文字
---@param x number 绘制坐标x
---@param y number 绘制坐标y
---@param str string 文字
---@param color number 颜色
---@param size number 字体大小
---@param fontname string 字体名
---@param charset string 简繁
---@param flag number? 可选，1加粗（效果不太好）
function lib.DrawStr(x, y, str, color, size, fontname, charset, flag) end

--- UI层，设置裁剪范围，后续只在两个坐标围城的矩形内绘制
---@param x1 number 左侧x
---@param y1 number 左侧y
---@param x2 number 右侧x
---@param y2 number 右侧y
function lib.SetClip(x1, y1, x2, y2) end

--- UI层，对矩形范围填充颜色
---@param x1 number 左侧x
---@param y1 number 左侧y
---@param x2 number 右侧x
---@param y2 number 右侧y
---@param color number 颜色
function lib.FillColor(x1, y1, x2, y2, color) end

--- UI层，默认填充黑色，可控制透明度
---@param x1 number 左侧x
---@param y1 number 左侧y
---@param x2 number 右侧x
---@param y2 number 右侧y
---@param bright number 透明度0-255
---@param color number? 不传默认黑色
function lib.Background(x1, y1, x2, y2, bright, color) end

--- UI层，绘制空心矩形
---@param x1 number 左侧x
---@param y1 number 左侧y
---@param x2 number 右侧x
---@param y2 number 右侧y
---@param color number 颜色
function lib.DrawRect(x1, y1, x2, y2, color) end

--- 绘制五边形
---@param centerX number 中心点x
---@param centerY number 中心点y
---@param radius number 半径
---@param points number 五个顶点的坐标
function lib.DrawPentagon(centerX, centerY, radius, points) end

--- 显示表面，自动组合所有纹理层
function lib.ShowSurface() end

--- 清空表面和所有纹理层
function lib.ClearSurface() end

--- Layer层，控制淡入淡出，持续时间内暂停其他层绘制
---@param duration number 持续时间
---@param flag number 0淡入，从暗到亮，1淡出，从亮到暗
function lib.ShowSlow(duration, flag) end

--- 窗口抖动，可以自行设置抖动参数
---@see lib.SetShake
---@param duration number 持续时间
function lib.Shake(duration) end

--- 设置抖动参数
---@param seed number 随机种子
---@param dircX number 设置抖动水平方向，左-1，右1
---@param dircY number 设置抖动垂直方向，上-1，下1
---@param speed number 抖动速度
---@param maxMagnitude number 抖动最大幅度
---@param noiseMagnitude number 抖动噪声幅度
---@param baseX number? 抖动基准点x，默认-1屏幕中心
---@param baseY number? 抖动基准点y，默认-1屏幕中心
function lib.SetShake(seed, dircX, dircY, speed, maxMagnitude, noiseMagnitude, baseX,
                      baseY)
end

--- 加载256色调色板，清空贴图缓存
---@param path string? 文件路径
function lib.PicInit(path) end

--- 获取贴图属性
---@param fileid number 贴图文件id
---@param picid number 贴图id
---@return number width, number height, number xoff, number yoff 宽，高，x偏移，y偏移
function lib.PicGetXY(fileid, picid) end

--- Scene层，绘制贴图
---@param fileid number 贴图文件id
---@param picid number 贴图id
---@param x number 绘制坐标x
---@param y number 绘制坐标y
---@param flag number? 1忽略偏移，2设置透明，4覆盖黑色，8覆盖白色，16自定义颜色
---@param value number? 根据flag设置不同数值
---@param color number? 根据flag设置不同颜色
---@param width number? 修改显示宽度
---@param height number? 修改显示高度
---@param renderTarget number? 修改渲染纹理层，0.Scene 1.UI 2.Layer 默认0
function lib.PicLoadCache(fileid, picid, x, y, flag, value, color, width, height, renderTarget) end

--- 缓存贴图文件
---@param idx string 索引文件名
---@param grp string 贴图组文件名
---@param id number 缓存id
---@param width number? 指定宽度
---@param height number? 指定高度
function lib.PicLoadFile(idx, grp, id, width, height) end

--- 窗口全屏控制
---@param flag number 0关闭全屏，1开启全屏
function lib.FullScreen(flag) end

--- UI层，绘制图片，初次加载后会缓存纹理，支持jpg png
---@param path string 图片路径
---@param x number 绘制坐标x
---@param y number 绘制坐标y
---@param destWidth number? 修改显示宽度
---@param destHeight number? 修改显示高度
function lib.LoadPicture(path, x, y, destWidth, destHeight) end

--- 获取图片宽高，与绘制函数共享缓存，但是返回的是图片原始宽高，并非绘制时指定的宽高
---@see lib.LoadPicture
---@param path string 图片路径
---@return number width, number height 宽，高
function lib.GetPictureWH(path) end

--- 播放音乐。全局同时只能播放一首，播其他音乐会立即停止当前音乐，但是重复播相同音乐不做任何处理
---@param path string 音乐文件路径
function lib.PlayBgm(path) end

--- 临时播放一首音乐。暂停当前播放的BGM，等临时的播完之后恢复
---@see lib.PlayBgm
---@param path string 音乐文件路径
function lib.PlayTempBgm(path) end

--- 停止播放BGM
function lib.StopBgm() end

--- 设置音乐音量
---@param volume number 0-100
function lib.SetVolume(volume) end

--- 播放WAV音效
---@param path string 音效文件路径
function lib.PlayWAV(path) end

--- 播放视频（未验证是否还有效）
---@param path string 视频文件路径
function lib.PlayMPEG(path) end

---加载大地图
---@param earth string 地面资源文件路径
---@param surface string 表面资源文件路径
---@param building string 建筑资源文件路径
---@param buildx number 建筑资源文件路径
---@param buildy number 建筑资源文件路径
---@param xmax number 地图x轴最大值
---@param ymax number 地图y轴最大值
---@param x number 地图x轴起始值
---@param y number 地图y轴起始值
function lib.LoadMMap(earth, surface, building, buildx, buildy, xmax, ymax, x, y) end

--- Scene层，绘制大地图
---@param x number 绘制坐标x
---@param y number 绘制坐标y
---@param mypic number 主角贴图id
---@param xoff number? x偏移，随flag表达不同数值
---@param yoff number? y偏移
---@param flag number? 0按瓦片格子计算偏移，1按像素计算偏移
function lib.DrawMMap(x, y, mypic, xoff, yoff, flag) end

--- 获取大地图贴图
---@param x number x轴坐标
---@param y number y轴坐标
---@param level number 层级，0 earth, 1 surface, 2 building, 3 buildx, 4 buildy
function lib.GetMMap(x, y, level) end

--- 释放大地图数据
function lib.UnloadMMap() end

--- 配置场景属性
---@param x_max number 场景x轴最大值
---@param y_max number 场景y轴最大值
---@param num number 场景数量
---@param d_num1 number 每个场景d数据数量
---@param d_num2 number 每个d数据属性数量
function lib.SetSMapConfig(x_max, y_max, num, d_num1, d_num2) end

--- 加载场景数据
---@param Sfilename string 场景s文件路径
---@param tempfilename string 临时s文件路径
---@param Dfilename string d文件路径
---@deprecated 改为加载0号存档内数据
function lib.LoadSMap(Sfilename, tempfilename, Dfilename) end

--- 场景数据写入到s、d文件中
---@param Sfilename string 场景s文件路径
---@param Dfilename string d文件路径
---@deprecated
function lib.SaveSMap(Sfilename, Dfilename) end

--- 获取场景S数据
---@param id number 场景id
---@param x number x轴坐标
---@param y number y轴坐标
---@param level number 层级，0-6
---@return number
function lib.GetS(id, x, y, level) end

--- 设置场景S数据
---@param id number 场景id
---@param x number x轴坐标
---@param y number y轴坐标
---@param level number 层级，0-6
---@param v number 设置的数据
function lib.SetS(id, x, y, level, v) end

--- 获取场景D数据
---@param sid number 场景id
---@param did number d数据id
---@param i number d数据索引
---@return number
function lib.GetD(sid, did, i) end

--- 设置场景D数据
---@param sid number 场景id
---@param did number d数据id
---@param i number d数据索引
---@param v number 设置的数据
function lib.SetD(sid, did, i, v) end

--- Scene层，绘制场景
---@param sceneid number 场景id
---@param x number 绘制坐标x
---@param y number 绘制坐标y
---@param xoff number x偏移
---@param yoff number y偏移
---@param mypic number 主角贴图id
---@param flag number 0按瓦片格子计算偏移，1按像素计算偏移
function lib.DrawSMap(sceneid, x, y, xoff, yoff, mypic, flag) end

--- UI层，按给定的宽高绘制出完整的场景
---@param sceneId number 场景id
---@param xoff number x偏移
---@param yoff number y偏移
---@param width number 指定宽度
---@param height number 指定高度
function lib.DrawSMap2(sceneId, xoff, yoff, width, height) end

--- 获取鼠标所在瓦片地图坐标
---@return number x, number y 大地图和场景有效，战斗场景无效
function lib.GetMousePosition() end

--- 地图坐标转屏幕坐标
---@param tx number 地图坐标x
---@param ty number 地图坐标y
---@param cx number 当前屏幕中心的地图坐标x
---@param cy number 当前屏幕中心的地图坐标y
---@return number x, number y
function lib.Map2Screen(tx, ty, cx, cy) end

--- 地图坐标转逻辑画布坐标
---@param tx number 地图坐标x
---@param ty number 地图坐标y
---@param cx number 当前屏幕中心的地图坐标x
---@param cy number 当前屏幕中心的地图坐标y
---@return number x, number y
function lib.Map2Logic(tx, ty, cx, cy) end

--- 屏幕坐标转地图坐标
---@param screenX number 屏幕坐标x
---@param screenY number 屏幕坐标y
---@param cx number 当前屏幕中心的地图坐标x
---@param cy number 当前屏幕中心的地图坐标y
---@param xoff number x偏移
---@param yoff number y偏移
---@param flag number 0按瓦片格子计算偏移，1按像素计算偏移
---@return number x, number y
function lib.Screen2Map(screenX, screenY, cx, cy, xoff, yoff, flag) end

--- 设置场景信息
---@param data [table] 所有场景的基本信息
function lib.SetSceneData(data) end

--- 加载战斗地图数据
---@param WarIDXfilename string 战斗地图IDX文件路径
---@param WarGRPfilename string 战斗地图GRP文件路径
---@param mapid number 战斗地图id
---@param num number 战斗地图数据层
---@param x_max number x轴最大值
---@param y_max number y轴最大值
function lib.LoadWarMap(WarIDXfilename, WarGRPfilename, mapid, num, x_max, y_max) end

--- 获取战斗地图数据
---@param x number x轴坐标
---@param y number y轴坐标
---@param level number 层级，规定0~8
---@return number
function lib.GetWarMap(x, y, level) end

--- 设置战斗地图数据
---@param x number x轴坐标
---@param y number y轴坐标
---@param level number 层级，规定0~8
---@param v number 设置的数据
function lib.SetWarMap(x, y, level, v) end

--- 实际作用为用指定数据覆盖整个层级
---@param level number 层级，规定0~8
---@param v number 覆盖值
function lib.CleanWarMap(level, v) end

--- Scene层，绘制战斗地图
---@param flag number 0绘制基本战斗地图；
---1显示可移动的路径，(v1,v2)当前移动坐标，白色背景(雪地战斗)；
---2同1，但黑色背景；
---3命中的人物用白色轮廓显示；
---4战斗动作动画（v1 战斗人物pic, v2贴图所属的加载文件id，v3 武功效果pic  -1表示没有武功效果）
---@param x number 绘制坐标x
---@param y number 绘制坐标y
---@param v1 number 根据flag发挥作用
---@param v2 number 根据flag发挥作用
---@param v3 number 根据flag发挥作用
---@param v4 number 根据flag发挥作用
---@param v5 number 根据flag发挥作用
---@param ex number 特效指定坐标x
---@param ey number 特效指定坐标y
function lib.DrawWarMap(flag, x, y, v1, v2, v3, v4, v5, ex, ey) end

--- 保存屏幕到临时表面，并返回临时表面id，之后可重复利用
---@see lib.LoadSur
---@param x number 保存的起始坐标x
---@param y number 保存的起始坐标y
---@param w number 保存的宽度
---@param h number 保存的高度
---@return number surId
function lib.SaveSur(x, y, w, h) end

--- UI层，绘制临时表面到纹理上（纹理分层后的临时做法，之后应按纹理层级管理临时表面）
---@param id number 临时表面id
---@param x number 绘制坐标x
---@param y number 绘制坐标y
function lib.LoadSur(id, x, y) end

--- 释放临时表面
---@param id number 临时表面id
function lib.FreeSur(id) end

--- 获取当前屏幕宽高
---@return number width, number height
function lib.GetScreenSize() end

--- 获取逻辑画布宽高
---@return number width, number height
function lib.GetLogicSize() end

--- 给一整个图片集缓存预设目录并申请空间
--- 若已存在缓存先清理旧的再重新申请，一般来说启动时申请一次就够了
--- 目录的图片名字必须都是纯数字
---@see lib.LoadPNG
---@see lib.LoadWEBP
---@param dir string 图片目录，如head body icon ui等
---@param fileid number 给此目录设定一个id，读取图片传id不传目录
---@param num number 预设图片数量，少于实际数量图片可能无法显示
---@param percent number? 指定图片比例
---@param suffix string? 图片后缀，默认png，实际取决于调了哪个函数
function lib.LoadPNGPath(dir, fileid, num, percent, suffix) end

--- UI层，绘制png图片，首次加载后生成缓存
--- 并不能自由选择路径，必须先配置目录
---@see lib.LoadPNGPath
---@param fileid number 图片目录id
---@param picid number 图片id
---@param x number 绘制坐标x
---@param y number 绘制坐标y
---@param flag number? 1忽略偏移，2图片左右翻转，4调整透明度
---@param value number? 随flag发挥作用
---@param destWidth number? 指定宽度
---@param destHeight number? 指定高度
function lib.LoadPNG(fileid, picid, x, y, flag, value, destWidth, destHeight) end

--- UI层，绘制webp图片，首次加载后生成缓存
--- 并不能自由选择路径，必须先配置目录
---@see lib.LoadPNGPath
---@param fileid number 图片目录id
---@param picid number 图片id
---@param x number 绘制坐标x
---@param y number 绘制坐标y
---@param flag number? 1忽略偏移，2图片左右翻转，4调整透明度
---@param value number? 随flag发挥作用
---@param destWidth number? 指定宽度
---@param destHeight number? 指定高度
function lib.LoadWEBP(fileid, picid, x, y, flag, value, destWidth, destHeight) end

--- 获取png图片的原始宽高，与绘制共享缓存
---@see lib.LoadPNG
---@param fileid number 图片目录id
---@param picid number 图片id
---@return number width, number height, number xoff, number yoff
function lib.GetPNGXY(fileid, picid) end

--- 获取webp图片的原始宽高，与绘制共享缓存
---@see lib.LoadWEBP
---@param fileid number 图片目录id
---@param picid number 图片id
---@return number width, number height, number xoff, number yoff
function lib.GetWebpXY(fileid, picid) end

--- 屏幕截图
---@param filename string 保存路径
---@param x number? 截图起始坐标x，默认0
---@param y number? 截图起始坐标y，默认0
---@param w number? 截图宽度，默认-1，即等同屏幕宽度
---@param h number? 截图高度，默认-1，即等同屏幕高度
function lib.ScreenShot(filename, x, y, w, h) end

--- 打开数据库
---@param path string 数据库路径
---@return boolean success 是否成功
---@see lib.ExecSql lib.CloseDB
function lib.OpenDB(path) end

--- 执行sql语句
---@param sql string sql语句
---@return [table] result 查询结果
---@see lib.OpenDB lib.CloseDB
function lib.ExecSql(sql) end

--- 关闭数据库
---@see lib.OpenDB lib.ExecSql
function lib.CloseDB() end

--- 读取ini文件数据
---@param section string 分类
---@param key string 键
---@return string value 值
function lib.GetConfigString(section, key) end

--- 读取ini文件数据
---@param section string 分类
---@param key string 键
---@return boolean value 值
function lib.GetConfigBool(section, key) end

--- 读取ini文件数据
---@param section string 分类
---@param key string 键
---@return integer value 值
function lib.GetConfigInt(section, key) end

--- 读取ini文件数据
---@param section string 分类
---@param key string 键
---@return number value 值
function lib.GetConfigReal(section, key) end

--- 写入ini文件数据
---@param section string 分类
---@param key string 键
---@param val string 值
function lib.SetConfigString(section, key, val) end

--- 写入ini文件数据
---@param section string 分类
---@param key string 键
---@param val boolean 值
function lib.SetConfigBool(section, key, val) end

--- 写入ini文件数据
---@param section string 分类
---@param key string 键
---@param val integer 值
function lib.SetConfigInt(section, key, val) end

--- 写入ini文件数据
---@param section string 分类
---@param key string 键
---@param val number 值
function lib.SetConfigReal(section, key, val) end

--- 加载proto协议的R数据文件
---@param path string 文件路径
function lib.LoadRanger(path) end

--- 加载proto协议的战斗数据文件
---@param path string 文件路径
function lib.LoadBattler(path) end

--- 获取角色数量
---@return number
function lib.GetPersonNum() end

--- 获取物品数量
---@return number
function lib.GetThingNum() end

--- 获取场景数量
---@return number
function lib.GetSceneNum() end

--- 获取武功数量
---@return number
function lib.GetWugongNum() end

--- 获取商店数量
---@return number
function lib.GetShopNum() end

--- 获取能力数量
---@return number
function lib.GetAbilityNum() end

--- 获取战斗数量
---@return number
function lib.GetBattleNum() end

---@class BattleRecorder
BattleRecorder = {}

--- 战斗录像的准备工作
---@param userdata userdata 要写录像数据的内存地址
---@param path string 录像文件保存的路径
---@param size number 环境数据大小
function BattleRecorder.prepare(userdata, path, size) end

--- 写入玩家操作到录像文件里
---@param time number 操作时间
---@param key number 按键
---@param ktype number 按键类型
---@param mx number 鼠标x坐标
---@param my number 鼠标y坐标
function BattleRecorder.write(time, key, ktype, mx, my) end

--- 关闭录像文件写入
function BattleRecorder.close() end

--- 录像文件列表
---@param dir string 录像文件夹
function BattleRecorder.list(dir) end

--- 读取录像数据
---@param path string 录像文件路径
---@param begin number 数据起始位置
---@param length number 读取的长度
---@return userdata data, boolean isJfRep, number totalSize 读取到的数据，是否正版录像，录像文件总大小
function BattleRecorder.load(path, begin, length) end

--- 删除旧录像文件
---@param dir string 录像文件夹
---@param max number 保留录像数量
function BattleRecorder.deleteOldFile(dir, max) end

---@class Byte
Byte = {}

--- 创建一个userdata
---@param size number 大小
---@return userdata data 内存地址
function Byte.create(size) end

--- 把文件读取到指定内存地址
---@param userdata userdata 内存地址
---@param path string 文件路径
---@param start number 起始位置
---@param length number 读取长度
function Byte.loadfile(userdata, path, start, length) end

--- 读取压缩文件到指定内存地址
---@param userdata userdata 内存地址
---@param zip_file string 压缩文件路径
---@param filename string 文件名
---@param start number 起始位置
---@param length number 读取长度
function Byte.loadfilefromzip(userdata, zip_file, filename, start, length) end

--- 保存数据到文件
---@param userdata userdata 内存地址
---@param filename string 文件路径
---@param start number 起始位置
---@param length number 保存长度
function Byte.savefile(userdata, filename, start, length) end

--- 解压文件到当前目录
---@param zip_path string 压缩文件路径
---@param ... string 要解压的文件名
function Byte.unzip(zip_path, ...) end

--- 压缩指定文件
---@param zip_file string 压缩文件路径
---@param ... string 要压缩的文件名
function Byte.zip(zip_file, ...) end

--- 游戏存档
---@param zip_file string 存档文件名
function Byte.saveRecord(zip_file) end

--- 游戏读档
---@param zip_file string 存档文件名
---@param s_x_max number 场景x轴最大值
---@param s_y_max number 场景y轴最大值
---@param d_num1 number 每个场景D数据数量
---@param d_num2 number 每个D数据的属性数量
function Byte.loadRecord(zip_file, s_x_max, s_y_max, d_num1, d_num2) end

--- 获取存档简要信息
---@param zip_file string 存档文件名
---@return table
function Byte.simpleRecordInfo(zip_file) end

--- 读取一个字节
---@param userdata userdata 内存地址
---@param start number 起始位置
---@return number
function Byte.get8(userdata, start) end

--- 读取两个字节
---@param userdata userdata 内存地址
---@param start number 起始位置
---@return number
function Byte.get16(userdata, start) end

--- 写入两个字节
---@param userdata userdata 内存地址
---@param start number 起始位置
---@param value number 值
function Byte.set16(userdata, start, value) end

--- 读取两个无符号字节
---@param userdata userdata 内存地址
---@param start number 起始位置
---@return number
function Byte.getu16(userdata, start) end

--- 写入两个无符号字节
---@param userdata userdata 内存地址
---@param start number 起始位置
---@param value number 值
function Byte.setu16(userdata, start, value) end

--- 读取四个字节
---@param userdata userdata 内存地址
---@param start number 起始位置
---@return number
function Byte.get32(userdata, start) end

--- 写入四个字节
---@param userdata userdata 内存地址
---@param start number 起始位置
---@param value number 值
function Byte.set32(userdata, start, value) end

--- 读取字符串
---@param userdata userdata 内存地址
---@param start number 起始位置
---@param length number 字符串长度
---@return string
function Byte.getstr(userdata, start, length) end

--- 写入字符串
---@param userdata userdata 内存地址
---@param start number 起始位置
---@param length number 字符串长度
---@param str number 值
function Byte.setstr(userdata, start, length, str) end
